@@ -1,4 +1,5 @@
 """main port-for functionality."""
+
 import contextlib
 import errno
 import random
@@ -185,9 +186,7 @@ def get_port(
     try:
         if not isinstance(ports, list):
             ports = [ports]
-        ranges: Set[int] = utils.ranges_to_set(
-            filter_by_type(ports, tuple)  # type: ignore[arg-type]
-        )
+        ranges: Set[int] = utils.ranges_to_set(filter_by_type(ports, tuple))
         nums: Set[int] = set(filter_by_type(ports, int))
         sets: Set[int] = set(
             chain(
